@@ -1,18 +1,19 @@
+from typing import Union
 from secrets import choice
 
 
 class PassGen:
-    def __init__(self, filename=None, char_limit=16):
+    def __init__(self, filename: Union[str, None] = None, char_limit: int = 16):
         self.char_limit = char_limit
         if filename is not None:
             self.word_list = filename
 
     @property
-    def char_limit(self):
+    def char_limit(self) -> int:
         return self.__char_limit
 
     @char_limit.setter
-    def char_limit(self, value):
+    def char_limit(self, value: int) -> None:
         if value < 16:
             print("Character limit must be at least 16 for security reasons.")
         else:
@@ -23,7 +24,7 @@ class PassGen:
         return self.__word_list
 
     @word_list.setter
-    def word_list(self, filename):
+    def word_list(self, filename) -> None:
         with open(filename, "r") as file:
             self.__word_list = [line.strip() for line in file.readlines()]
 
